function demo3D10( param )
% demo3D10
%
% Synthesize 1 instance using a lamp2 model with sampling mode
% set to 'disc' and no convolution.
% Results will be three .obj files, one each for 
% cell boundary, nuclear boundary, and lamp2, 
% in folder "synthesizedImages/cell1"

% Created: Robert F. Murphy
%
% Copyright (C) 2012 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

curr_path = which('demo3D10.m');
curr_path = curr_path(1:end-10);
cd(curr_path);

outputDirectory = pwd;
if nargin == 0
    param = [];
end

param = ml_initparam( param, ...
    struct( 'numberOfSynthesizedImages', 1 ) );
param = ml_initparam( param, ...
    struct( 'seed', 255 ) );

outputDirectory = pwd;
param.targetDirectory = outputDirectory;
param.prefix = 'synthesizedImages';
param.compression = 'lzw';
param.microscope = 'none';
param.sampling.method = 'disc';
param.verbose = true;
param.debug = false;
param.output.tifimages = true;
param.output.blenderfile = true;
param.output.blender.downsample = 5;

try
 state = rng( param.seed );
catch
 state = RandStream.create('mt19937ar','seed', param.seed );
 RandStream.setDefaultStream(state);
end

ansswer = slml2img( {'../../../models/3D/lamp2.mat'}, param );

